==> totoui-0.3.0.tgz: package/lib/input.js <==
'use strict';

/**
 * Inputs Components
 * @desc includes input, input-group
 */

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _minxinsConstantsJs = require('./minxins/constants.js');

var _minxinsConstantsJs2 = _interopRequireDefault(_minxinsConstantsJs);

var _formGroupJsx = require('./formGroup.js');

var _formGroupJsx2 = _interopRequireDefault(_formGroupJsx);

var _buttonJsx = require('./button.js');

var _buttonJsx2 = _interopRequireDefault(_buttonJsx);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var Input = (function (_React$Component) {
    _inherits(Input, _React$Component);

    function Input(props) {
        _classCallCheck(this, Input);

        _get(Object.getPrototypeOf(Input.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }

        this.getFieldDOMNode = this.getFieldDOMNode.bind(this);
        this.getValue = this.getValue.bind(this);

        this.isCheckboxOrRadio = this.isCheckboxOrRadio.bind(this);
        this.isFile = this.isFile.bind(this);
        this.renderInput = this.renderInput.bind(this);
        this.renderWrapper = this.renderWrapper.bind(this);
        this.renderCheckboxAndRadioWrapper = this.renderCheckboxAndRadioWrapper.bind(this);
        this.renderLabel = this.renderLabel.bind(this);
        this.renderInputGroup = this.renderInputGroup.bind(this);
        this.renderHelp = this.renderHelp.bind(this);
        this.renderIcon = this.renderIcon.bind(this);
    }

    _createClass(Input, [{
        key: 'getFieldDOMNode',
        value: function getFieldDOMNode() {
            return _react2['default'].findDOMNode(this.refs.field);
        }
    }, {
        key: 'getValue',
        value: function getValue() {
            if (this.props.type === 'select' && this.props.multiple) {
                return this.getSelectedOptions();
            } else {
                return this.getFieldDOMNode().value;
            }
        }
    }, {
        key: 'getChecked',
        value: function getChecked() {
            return this.getFieldDOMNode().checked;
        }
    }, {
        key: 'getSelectedOptions',
        value: function getSelectedOptions() {
            var values = [];
            var options = this.getFieldDOMNode().getElementsByTagName('option');

            options.forEach(function (option) {
                if (option.selected) {
                    var value = option.getAttribute('value') || option.innerHtml;

                    values.push(value);
                }
            });

            return values;
        }
    }, {
        key: 'isCheckboxOrRadio',
        value: function isCheckboxOrRadio() {
            return this.props.type === 'radio' || this.props.type === 'checkbox';
        }
    }, {
        key: 'isFile',
        value: function isFile() {
            return this.props.type === 'file';
        }
    }, {
        key: 'renderInput',
        value: function renderInput() {
            var input = null;
            var fieldClassName = this.isCheckboxOrRadio() || this.isFile() ? '' : this.setClassNamespace('form-field');
            var classSet = {};

            classSet[_minxinsConstantsJs2['default'].CLASSES.round] = this.props.round;
            classSet[_minxinsConstantsJs2['default'].CLASSES.radius] = this.props.radius;

            if (this.props.amSize && !this.props.standalone) {
                classSet[this.setClassNamespace('input-' + this.props.amSize)] = true;
            }

            var classes = (0, _classnames2['default'])(this.props.className, fieldClassName, classSet);

            switch (this.props.type) {
                case 'select':
                    input = _react2['default'].createElement(
                        'select',
                        _extends({}, this.props, {
                            className: classes,
                            ref: "field", key: "field" }),
                        this.props.children
                    );
                    break;
                case 'textarea':
                    input = _react2['default'].createElement('textarea', _extends({}, this.props, {
                        className: classes,
                        ref: "field",
                        key: "field" }));
                    break;
                case 'submit':
                case 'reset':
                    input = _react2['default'].createElement(_buttonJsx2['default'], _extends({}, this.props, {
                        componentTag: "input",
                        ref: "field",
                        key: "field" }));
                    break;
                default:
                    input = _react2['default'].createElement('input', _extends({}, this.props, {
                        className: classes,
                        ref: "field",
                        key: "field" }));
            }

            return input;
        }

        // Input wrapper if wrapperClassName set
    }, {
        key: 'renderWrapper',
        value: function renderWrapper(children) {
            return this.props.wrapperClassName ? _react2['default'].createElement(
                'div',
                {
                    className: this.props.wrapperClassName,
                    key: "wrapper" },
                children
            ) : children;
        }

        // Wrap block checkbox/radio
    }, {
        key: 'renderCheckboxAndRadioWrapper',
        value: function renderCheckboxAndRadioWrapper(children) {
            // Don't wrap inline checkbox/radio
            return this.props.inline ? children : _react2['default'].createElement(
                'div',
                {
                    className: this.setClassNamespace(this.props.type),
                    key: "checkboxAndRadioWrapper" },
                children
            );
        }
    }, {
        key: 'renderLabel',
        value: function renderLabel(children) {
            // label doesn't work with icon
            /*if (this.props.icon) {
             return null;
             }*/

            var classSet = {};

            if (this.isCheckboxOrRadio()) {
                // inline checkbox and radio
                this.props.inline && (classSet[this.setClassNamespace(this.props.type + '-inline')] = true);
            } else {
                // normal form label
                classSet[this.setClassNamespace('form-label')] = true;
            }

            return this.props.label ? _react2['default'].createElement(
                'label',
                {
                    htmlFor: this.props.id,
                    className: (0, _classnames2['default'])(this.props.labelClassName, classSet),
                    key: "label" },
                children,
                this.props.label
            ) : children;
        }
    }, {
        key: 'renderInputGroup',
        value: function renderInputGroup(children) {
            var groupPrefix = this.setClassNamespace('input-group');
            var addonClassName = groupPrefix + '-label';
            var btnClassName = groupPrefix + '-btn';
            var addonBefore = this.props.addonBefore ? _react2['default'].createElement(
                'span',
                { className: addonClassName, key: "addonBefore" },
                this.props.addonBefore
            ) : null;
            var addonAfter = this.props.addonAfter ? _react2['default'].createElement(
                'span',
                { className: addonClassName, key: "addonAfter" },
                this.props.addonAfter
            ) : null;
            var btnBefore = this.props.btnBefore ? _react2['default'].createElement(
                'span',
                { className: btnClassName, key: "btnBefore" },
                this.props.btnBefore
            ) : null;
            var btnAfter = this.props.btnAfter ? _react2['default'].createElement(
                'span',
                { className: btnClassName, key: "btnAfter" },
                this.props.btnAfter
            ) : null;
            var classSet = {};

            if (this.props.amSize) {
                classSet[groupPrefix + '-' + this.props.amSize] = true;
            }

            if (this.props.amStyle) {
                classSet[groupPrefix + '-' + this.props.amStyle] = true;
            }

            return addonBefore || addonAfter || btnBefore || btnAfter ? _react2['default'].createElement(
                'div',
                {
                    className: (0, _classnames2['default'])(groupPrefix, classSet),
                    key: "inputGroup" },
                addonBefore,
                btnBefore,
                children,
                addonAfter,
                btnAfter
            ) : children;
        }

        // form help
    }, {
        key: 'renderHelp',
        value: function renderHelp() {
            return this.props.help ? _react2['default'].createElement(
                'p',
                {
                    className: (0, _classnames2['default'])(this.setClassNamespace('form-help'), this.props.helpClassName),
                    key: "help" },
                this.props.help
            ) : '';
        }
    }, {
        key: 'renderIcon',
        value: function renderIcon() {
            // TODO: replace with Icon component
            var props = this.props;
            var feedbackIcon = {
                success: 'check',
                warning: 'warning',
                error: 'times'
            };
            var icon = props.icon || props.hasFeedback && props.validation && feedbackIcon[props.validation];

            return icon ? _react2['default'].createElement(_iconJsx2['default'], { icon: icon, key: "icon" }) : null;
        }
    }, {
        key: 'render',
        value: function render() {
            // standalone mode
            if (this.props.standalone) {
                return this.renderInput();
            }

            // render checkbox and radio, without FormGroup wrapper
            if (this.isCheckboxOrRadio()) {
                return this.renderWrapper(this.renderCheckboxAndRadioWrapper(this.renderLabel(this.renderInput())));
            }

            var groupClassName = (0, _classnames2['default'])(this.props.type === 'select' ? this.setClassNamespace('form-select') : null, this.props.icon && this.setClassNamespace('form-icon'), this.props.groupClassName);

            return _react2['default'].createElement(
                _formGroupJsx2['default'],
                {
                    className: groupClassName,
                    validation: this.props.validation,
                    amSize: this.props.amSize,
                    hasFeedback: this.props.hasFeedback },
                [this.renderLabel(), this.renderWrapper(this.renderInputGroup(this.renderInput())), this.renderIcon(), this.renderHelp()]
            );
        }
    }]);

    return Input;
})(_react2['default'].Component);

Input.displayName = "Input";

Input.propTypes = {
    type: _react2['default'].PropTypes.string,
    disabled: _react2['default'].PropTypes.bool,
    radius: _react2['default'].PropTypes.bool,
    round: _react2['default'].PropTypes.bool,
    amSize: _react2['default'].PropTypes.oneOf(['sm', 'lg']),
    amStyle: _react2['default'].PropTypes.string,
    validation: _react2['default'].PropTypes.oneOf(['success', 'warning', 'error']),
    label: _react2['default'].PropTypes.node,
    help: _react2['default'].PropTypes.node,
    addonBefore: _react2['default'].PropTypes.node,
    addonAfter: _react2['default'].PropTypes.node,
    btnBefore: _react2['default'].PropTypes.node,
    btnAfter: _react2['default'].PropTypes.node,
    id: _react2['default'].PropTypes.string,
    groupClassName: _react2['default'].PropTypes.string,
    wrapperClassName: _react2['default'].PropTypes.string,
    labelClassName: _react2['default'].PropTypes.string,
    helpClassName: _react2['default'].PropTypes.string,
    icon: _react2['default'].PropTypes.string,
    standalone: _react2['default'].PropTypes.bool,
    inline: _react2['default'].PropTypes.bool,
    hasFeedback: _react2['default'].PropTypes.bool
};

Input.defaultProps = {
    type: 'text'
};

module.exports = Input;

==> totoui-0.5.1.tgz: package/lib/input.js <==
'use strict';

/**
 * Inputs Components
 * @desc includes input, input-group
 */

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _mixinsConstantsJs = require('./mixins/constants.js');

var _mixinsConstantsJs2 = _interopRequireDefault(_mixinsConstantsJs);

var _formGroupJsx = require('./formGroup.js');

var _formGroupJsx2 = _interopRequireDefault(_formGroupJsx);

var _buttonJsx = require('./button.js');

var _buttonJsx2 = _interopRequireDefault(_buttonJsx);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var Input = (function (_React$Component) {
    _inherits(Input, _React$Component);

    function Input(props) {
        _classCallCheck(this, Input);

        _get(Object.getPrototypeOf(Input.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }

        this.getFieldDOMNode = this.getFieldDOMNode.bind(this);
        this.getValue = this.getValue.bind(this);

        this.isCheckboxOrRadio = this.isCheckboxOrRadio.bind(this);
        this.isFile = this.isFile.bind(this);
        this.renderInput = this.renderInput.bind(this);
        this.renderWrapper = this.renderWrapper.bind(this);
        this.renderCheckboxAndRadioWrapper = this.renderCheckboxAndRadioWrapper.bind(this);
        this.renderLabel = this.renderLabel.bind(this);
        this.renderInputGroup = this.renderInputGroup.bind(this);
        this.renderHelp = this.renderHelp.bind(this);
        this.renderIcon = this.renderIcon.bind(this);
    }

    _createClass(Input, [{
        key: 'getFieldDOMNode',
        value: function getFieldDOMNode() {
            return _reactDom2['default'].findDOMNode(this.refs.field);
        }

        /*.0.0.1.0.0.$field .0.0.1.0.0.$field*/
    }, {
        key: 'getValue',
        value: function getValue() {
            if (this.props.type === 'select' && this.props.multiple) {
                return this.getSelectedOptions();
            } else {
                return this.getFieldDOMNode().value;
            }
        }
    }, {
        key: 'getChecked',
        value: function getChecked() {
            return this.getFieldDOMNode().checked;
        }
    }, {
        key: 'getSelectedOptions',
        value: function getSelectedOptions() {
            var values = [];
            var options = this.getFieldDOMNode().getElementsByTagName('option');

            options.forEach(function (option) {
                if (option.selected) {
                    var value = option.getAttribute('value') || option.innerHtml;

                    values.push(value);
                }
            });

            return values;
        }
    }, {
        key: 'isCheckboxOrRadio',
        value: function isCheckboxOrRadio() {
            return this.props.type === 'radio' || this.props.type === 'checkbox';
        }
    }, {
        key: 'isFile',
        value: function isFile() {
            return this.props.type === 'file';
        }
    }, {
        key: 'renderInput',
        value: function renderInput() {
            var input = null;
            var fieldClassName = this.isCheckboxOrRadio() || this.isFile() ? '' : this.setClassNamespace('form-field');
            var classSet = {};

            classSet[_mixinsConstantsJs2['default'].CLASSES.round] = this.props.round;
            classSet[_mixinsConstantsJs2['default'].CLASSES.radius] = this.props.radius;

            if (this.props.amSize && !this.props.standalone) {
                classSet[this.setClassNamespace('input-' + this.props.amSize)] = true;
            }

            var classes = (0, _classnames2['default'])(this.props.className, fieldClassName, classSet);
            switch (this.props.type) {
                case 'select':
                    input = _react2['default'].createElement(
                        'select',
                        _extends({}, this.props, {
                            className: classes,
                            ref: 'field', key: 'field' }),
                        this.props.children
                    );
                    break;
                case 'textarea':
                    input = _react2['default'].createElement('textarea', _extends({}, this.props, {
                        className: classes,
                        ref: 'field',
                        key: 'field' }));
                    break;
                case 'submit':
                case 'reset':
                    input = _react2['default'].createElement(_buttonJsx2['default'], _extends({}, this.props, {
                        componentTag: 'input',
                        ref: 'field',
                        key: 'field' }));
                    break;
                default:
                    input = _react2['default'].createElement('input', _extends({}, this.props, {
                        className: classes,
                        ref: 'field',
                        key: 'field' }));
            }

            return input;
        }

        // Input wrapper if wrapperClassName set
    }, {
        key: 'renderWrapper',
        value: function renderWrapper(children) {
            return this.props.wrapperClassName ? _react2['default'].createElement(
                'div',
                {
                    className: this.props.wrapperClassName,
                    key: 'wrapper' },
                children
            ) : children;
        }

        // Wrap block checkbox/radio
    }, {
        key: 'renderCheckboxAndRadioWrapper',
        value: function renderCheckboxAndRadioWrapper(children) {
            // Don't wrap inline checkbox/radio
            return this.props.inline ? children : _react2['default'].createElement(
                'div',
                {
                    className: this.setClassNamespace(this.props.type),
                    key: 'checkboxAndRadioWrapper' },
                children
            );
        }
    }, {
        key: 'renderLabel',
        value: function renderLabel(children) {
            // label doesn't work with icon
            /*if (this.props.icon) {
             return null;
             }*/

            var classSet = {};

            if (this.isCheckboxOrRadio()) {
                // inline checkbox and radio
                this.props.inline && (classSet[this.setClassNamespace(this.props.type + '-inline')] = true);
            } else {
                // normal form label
                classSet[this.setClassNamespace('form-label')] = true;
            }

            return this.props.label ? _react2['default'].createElement(
                'label',
                {
                    htmlFor: this.props.id,
                    className: (0, _classnames2['default'])(this.props.labelClassName, classSet),
                    key: 'label' },
                children,
                this.props.label
            ) : children;
        }
    }, {
        key: 'renderInputGroup',
        value: function renderInputGroup(children) {
            var groupPrefix = this.setClassNamespace('input-group');
            var addonClassName = groupPrefix + '-label';
            var btnClassName = groupPrefix + '-btn';
            var addonBefore = this.props.addonBefore ? _react2['default'].createElement(
                'span',
                { className: addonClassName, key: 'addonBefore' },
                this.props.addonBefore
            ) : null;
            var addonAfter = this.props.addonAfter ? _react2['default'].createElement(
                'span',
                { className: addonClassName, key: 'addonAfter' },
                this.props.addonAfter
            ) : null;
            var btnBefore = this.props.btnBefore ? _react2['default'].createElement(
                'span',
                { className: btnClassName, key: 'btnBefore' },
                this.props.btnBefore
            ) : null;
            var btnAfter = this.props.btnAfter ? _react2['default'].createElement(
                'span',
                { className: btnClassName, key: 'btnAfter' },
                this.props.btnAfter
            ) : null;
            var classSet = {};

            if (this.props.amSize) {
                classSet[groupPrefix + '-' + this.props.amSize] = true;
            }

            if (this.props.amStyle) {
                classSet[groupPrefix + '-' + this.props.amStyle] = true;
            }

            return addonBefore || addonAfter || btnBefore || btnAfter ? _react2['default'].createElement(
                'div',
                {
                    className: (0, _classnames2['default'])(groupPrefix, classSet),
                    key: 'inputGroup' },
                addonBefore,
                btnBefore,
                children,
                addonAfter,
                btnAfter
            ) : children;
        }

        // form help
    }, {
        key: 'renderHelp',
        value: function renderHelp() {
            return this.props.help ? _react2['default'].createElement(
                'p',
                {
                    className: (0, _classnames2['default'])(this.setClassNamespace('form-help'), this.props.helpClassName),
                    key: 'help' },
                this.props.help
            ) : '';
        }
    }, {
        key: 'renderIcon',
        value: function renderIcon() {
            // TODO: replace with Icon component
            var props = this.props;
            var feedbackIcon = {
                success: 'check',
                warning: 'warning',
                error: 'times'
            };
            var icon = props.icon || props.hasFeedback && props.validation && feedbackIcon[props.validation];

            return icon ? _react2['default'].createElement(_iconJsx2['default'], { icon: icon, key: 'icon' }) : null;
        }
    }, {
        key: 'render',
        value: function render() {
            // standalone mode
            if (this.props.standalone) {
                return this.renderInput();
            }

            // render checkbox and radio, without FormGroup wrapper
            if (this.isCheckboxOrRadio()) {
                return this.renderWrapper(this.renderCheckboxAndRadioWrapper(this.renderLabel(this.renderInput())));
            }

            var groupClassName = (0, _classnames2['default'])(this.props.type === 'select' ? this.setClassNamespace('form-select') : null, this.props.icon && this.setClassNamespace('form-icon'), this.props.groupClassName);

            return _react2['default'].createElement(
                _formGroupJsx2['default'],
                {
                    className: groupClassName,
                    validation: this.props.validation,
                    amSize: this.props.amSize,
                    hasFeedback: this.props.hasFeedback },
                [this.renderLabel(), this.renderWrapper(this.renderInputGroup(this.renderInput())), this.renderIcon(), this.renderHelp()]
            );
        }
    }]);

    return Input;
})(_react2['default'].Component);

Input.displayName = "Input";

Input.propTypes = {
    type: _react2['default'].PropTypes.string,
    disabled: _react2['default'].PropTypes.bool,
    radius: _react2['default'].PropTypes.bool,
    round: _react2['default'].PropTypes.bool,
    amSize: _react2['default'].PropTypes.oneOf(['sm', 'lg']),
    amStyle: _react2['default'].PropTypes.string,
    validation: _react2['default'].PropTypes.oneOf(['success', 'warning', 'error']),
    label: _react2['default'].PropTypes.node,
    help: _react2['default'].PropTypes.node,
    addonBefore: _react2['default'].PropTypes.node,
    addonAfter: _react2['default'].PropTypes.node,
    btnBefore: _react2['default'].PropTypes.node,
    btnAfter: _react2['default'].PropTypes.node,
    id: _react2['default'].PropTypes.string,
    groupClassName: _react2['default'].PropTypes.string,
    wrapperClassName: _react2['default'].PropTypes.string,
    labelClassName: _react2['default'].PropTypes.string,
    helpClassName: _react2['default'].PropTypes.string,
    icon: _react2['default'].PropTypes.string,
    standalone: _react2['default'].PropTypes.bool,
    inline: _react2['default'].PropTypes.bool,
    hasFeedback: _react2['default'].PropTypes.bool
};

Input.defaultProps = {
    type: 'text'
};

module.exports = Input;
